replace_dict = {
    r'\\\"': r'',
    r'\\u0026': r'&',
    r'\u0026': r'&',
    r'\\"': r"'",
    r'\"': r"'",
    r'\\': r'',
    r'\/': r'/',
    r'\u003c': r'<',
    r'\u003e': r'>',
}

decode_dict = {
    ' ': '%20',
    '"': '%22',
    '#': '%23',
    '%': '%25',
    '&': '%26',
    '(': '%28',
    ')': '%29',
    '+': '%2B',
    ',': '%2C',
    '/': '%2F',
    ':': '%3A',
    ';': '%3B',
    '<': '%3C',
    '=': '%3D',
    '>': '%3E',
    '?': '%3F',
    '@': '%40',
    '\\': '%5C',
    '|': '%7C',
}

default_settings = {
    'save_to' : None,
    'file_name' : None,
    'quality' : None,
    'index' : None,
    'dl_range' : (),
    'dl_list' : [], 
    'retries' : 2,
    }